@@ -419,6 +419,7 @@ void KsGLWidget::keyReleaseEvent(QKeyEvent *event)
 
 void KsGLWidget::_defaultPlots(kshark_context *kshark_ctx)
 {
+	struct kshark_data_stream *stream;
 	QVector<int> streamIds, plotVec;
 	uint64_t tMin, tMax;
 	int nCPUs, nBins;
@@ -432,15 +433,19 @@ void KsGLWidget::_defaultPlots(kshark_context *kshark_ctx)
 	 */
 	streamIds = KsUtils::getStreamIdList(kshark_ctx);
 	for (auto const &sd: streamIds) {
-		nCPUs = kshark_ctx->stream[sd]->n_cpus;
+		stream = kshark_ctx->stream[sd];
+		nCPUs = stream->n_cpus;
 		plotVec.clear();
 
 		/* If the number of CPUs is too big show only the first 16. */
 		if (nCPUs > KS_MAX_START_PLOTS / kshark_ctx->n_streams)
 			nCPUs = KS_MAX_START_PLOTS / kshark_ctx->n_streams;
 
-		for (int i = 0; i < nCPUs; ++i)
-			plotVec.append(i);
+		for (int cpu{0}; cpu < stream->n_cpus && plotVec.count() < nCPUs; ++cpu) {
+			/* Do not add plots for idle CPUs. */
+			if (!kshark_hash_id_find(stream->idle_cpus, cpu))
+				plotVec.append(cpu);
+		}
 
 		_streamPlots[sd]._cpuList = plotVec;
 		_streamPlots[sd]._taskList = {};
